@@ -5,7 +5,9 @@ from panel.io import init_doc, state
 from panel.layout import Column, Panel, Card, WidgetBox
 
 from panel.pane import PaneBase
+
 from .widgets import PydanticModelEditor, PydanticModelEditorCard
+from .dispatchers import get_widget
 
 from typing import (
     Any,
@@ -19,45 +21,37 @@ from pyviz_comms import Comm
 
 
 class Pydantic(PaneBase):
-    '''pydantic Pane so that calling pn.panel(model)
+    """pydantic Pane so that calling pn.panel(model)
     will work. This pane is not expected to be used directly.
-    '''
-    
+    """
+
     default_layout = param.ClassSelector(
-        default=Column, class_=Panel, is_instance=False
+        default=WidgetBox, class_=Panel, is_instance=False
     )
 
-    object = param.Parameter()
+    
+    object = param.Parameter(default=None)
 
     def __init__(self, object=None, **params):
 
-        pane_params = {name: params[name] 
-                       for name in Pydantic.param.params()
-                       if name in params}
+        pane_params = {
+            name: params[name] for name in Pydantic.param.params() if name in params
+        }
 
         super().__init__(object, **pane_params)
 
-        Editor = PydanticModelEditor
-        if self.default_layout is Card:
-            Editor = PydanticModelEditorCard
 
-        editor_params = {name: params[name] 
-                         for name in Editor.param.params()
-                         if name in params}
-        
         if isinstance(object, pydantic.BaseModel):
-            self.widget = Editor(value=object, 
-                                 class_=object.__class__, **editor_params)
+            self.widget = get_widget(object, None, class_=object.__class__, **params)
             self.object = object
 
         elif issubclass(object, pydantic.BaseModel):
-            self.widget = Editor(class_=object, **editor_params)
+            self.widget = get_widget.invoke(object, None)(None, None, class_=object, **params)
             self.widget.link(self, value="object")
         else:
             raise
 
-        self.layout = WidgetBox(self.widget)
-
+        self.layout = self.default_layout(self.widget)
 
     def _get_model(
         self,
@@ -78,8 +72,10 @@ class Pydantic(PaneBase):
     def applies(cls, obj: Any, **params) -> Optional[bool]:
         if isinstance(obj, pydantic.BaseModel):
             return True
+            
         if issubclass(obj, pydantic.BaseModel):
             return True
+        return False
 
     def select(self, selector=None):
         """
